@@ -3,40 +3,51 @@
  * SPDX-License-Identifier: MPL-2.0
  */
 
-import { FileBase } from "projen";
+import { FileBase, IResolver, License } from "projen";
 import { JsiiProject } from "projen/lib/cdk";
 import { ConstructLibraryCdktf } from "projen/lib/cdktf";
-import { NpmAccess } from "projen/lib/javascript";
+import { NpmAccess, UpgradeDependenciesSchedule } from "projen/lib/javascript";
+import { TypeScriptProject } from "projen/lib/typescript";
+
+const SPDX = "MPL-2.0";
+
+class CustomizedLicense extends License {
+  constructor(project: TypeScriptProject) {
+    super(project, { spdx: SPDX });
+
+    project.addFields({ license: SPDX });
+  }
+
+  synthesizeContent(resolver: IResolver) {
+    return (
+      "Copyright (c) 2022 HashiCorp, Inc.\n\n" +
+      super.synthesizeContent(resolver)
+    );
+  }
+}
 
 const project = new ConstructLibraryCdktf({
-  author: "Daniel Schmidt",
-  authorAddress: "danielmschmidt92@gmail.com",
+  author: "HashiCorp",
+  authorAddress: "https://hashicorp.com",
+  authorOrganization: true,
   defaultReleaseBranch: "main",
   name: "@cdktf/tf-module-stack",
-  repositoryUrl: "https://github.com/DanielMSchmidt/cdktf-tf-module-stack.git",
+  repositoryUrl: "https://github.com/cdktf/cdktf-tf-module-stack.git",
   prettier: true,
   projenrcTs: true,
-  githubOptions: {
-    mergify: true,
-    mergifyOptions: {
-      rules: [
-        {
-          name: "Automatically merge auto-approve PRs",
-          conditions: ["label=auto-approve", "author=team-tf-cdk "],
-          actions: {
-            merge: {
-              method: "rebase",
-            },
-          },
-        },
-      ],
-    },
-  },
+  licensed: false,
   npmAccess: NpmAccess.PUBLIC,
   autoApproveUpgrades: true,
   autoApproveOptions: {
+    allowedUsernames: ["team-tf-cdk"],
     label: "auto-approve",
   },
+  depsUpgradeOptions: {
+    workflowOptions: {
+      labels: ["auto-approve", "dependencies"],
+      schedule: UpgradeDependenciesSchedule.WEEKLY,
+    },
+  },
   minMajorVersion: 1,
   cdktfVersion: ">=0.14.0",
   description:
@@ -76,6 +87,8 @@ project.addDevDeps(
   "@cdktf/provider-random@>=5.0.0"
 );
 
+new CustomizedLicense(project);
+
 interface JsiiDocgenOptions {
   /**
    * File path for generated docs.
@@ -159,8 +172,7 @@ project.addKeywords("cdktf", "terraform");
 project.buildWorkflow?.addPostBuildSteps(
   {
     name: "Setup Copywrite tool",
-    uses: "hashicorp/setup-copywrite@3ace06ad72e6ec679ea8572457b17dbc3960b8ce", // v1.0.0
-    with: { token: "${{ secrets.GITHUB_TOKEN }}" },
+    uses: "hashicorp/setup-copywrite@867a1a2a064a0626db322392806428f7dc59cb3e", // v1.1.2
   },
   { name: "Add headers using Copywrite tool", run: "copywrite headers" }
 );
